External API — turbo-turtle 1.2.5 documentation

Skip to main content
`Ctrl`+`K`

# External API

## scons_extensions

turbo_turtle.scons_extensions.cli_builder(

  program: str = 'turbo-turtle',
  subcommand: str = '',
  required: str = '',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a generic Turbo-Turtle CLI builder.

  This builder provides a template action for the Turbo-Turtle CLI. The default behavior will not do anything unless the `subcommand` argument is updated to one of the Turbo-Turtle CLI Sub-commands.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  This builder and any builders created from this template will be most useful if the `options` argument places SCons substitution variables in the action string, e.g. `--argument ${argument}`, such that the task definitions can modify the options on a per-task basis. Any option set in this manner must be provided by the task definition.

  Builder/Task keyword arguments

  - `program`: The Turbo-Turtle command line executable absolute or relative path

  - `subcommand`: A Turbo-Turtle subcommand

  - `required`: A space delimited string of subcommand required arguments

  - `options`: A space delimited string of subcommand optional arguments

  - `abaqus_command`: The Abaqus command line executable absolute or relative path. When provided as a task keyword argument, this must be a space delimited string, not a list.

  - `cubit_command`: The Cubit command line executable absolute or relative path. When provided as a task keyword argument, this must be a space delimited string, not a list.

  - `backend`: The backend software, e.g. Abaqus or Cubit.

  - `cd_action_prefix`: Advanced behavior. Most users should accept the defaults.

  - `redirect_action_postfix`: Advanced behavior. Most users should accept the defaults.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend {backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleCLIBuilder": turbo_turtle.scons_extensions.cli_builder(
              program=env["turbo_turtle],
              subcommand="geometry",
              required="--input-file ${SOURCES.abspath} --output-file ${TARGET.abspath}"
          )
      })
      env.TurboTurtleCLIBuilder(
          target=["target.cae"],
          source=["source.csv"],
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

  Returns:

    SCons Turbo-Turtle CLI builder

turbo_turtle.scons_extensions.cylinder(

  program: str = 'turbo-turtle',
  subcommand: str = 'cylinder',
  required: str = '--output-file ${TARGET.abspath} --inner-radius ${inner_radius} --outer-radius ${outer_radius} --height ${height}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle cylinder subcommand CLI builder

  See the cylinder CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  Unless the `required` argument is overridden, the following task keyword arguments are required:

  - `inner_radius`

  - `outer_radius`

  - `height`

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleCylinder": turbo_turtle.scons_extensions.cylinder(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleCylinder(
          target=["target.cae"],
          source=["SConstruct"],
          inner_radius=1.,
          outer_radius=2.,
          height=1.
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.export(

  program: str = 'turbo-turtle',
  subcommand: str = 'export',
  required: str = '--input-file ${SOURCE.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle export subcommand CLI builder

  See the export CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleExport": turbo_turtle.scons_extensions.export(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleExport(
          target=["target.inp"],
          source=["source.cae"],
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.geometry(

  program: str = 'turbo-turtle',
  subcommand: str = 'geometry',
  required: str = '--input-file ${SOURCES.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle geometry subcommand CLI builder

  See the geometry CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleGeometry": turbo_turtle.scons_extensions.geometry(
              program=env["turbo_turtle],
              options="--part-name ${part_name}"
          )
      })
      env.TurboTurtleGeometry(
          target=["target.cae"],
          source=["source1.csv", "source2.csv"],
          part_name="source1 source2"
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.geometry_xyplot(

  program: str = 'turbo-turtle',
  subcommand: str = 'geometry-xyplot',
  required: str = '--input-file ${SOURCES.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle geometry-xyplot subcommand CLI builder

  See the geometry-xyplot CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleGeometryXYPlot": turbo_turtle.scons_extensions.geometry_xyplot(
              program=env["turbo_turtle],
              options="--part-name ${part_name}"
          )
      })
      env.TurboTurtleGeometryXYPlot(
          target=["target.png"],
          source=["source1.csv", "source2.csv"],
          part_name="source1 source2"
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.image(

  program: str = 'turbo-turtle',
  subcommand: str = 'image',
  required: str = '--input-file ${SOURCE.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle image subcommand CLI builder

  See the image CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleImage": turbo_turtle.scons_extensions.image(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleImage(
          target=["target.png"],
          source=["source.cae"],
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.merge(

  program: str = 'turbo-turtle',
  subcommand: str = 'merge',
  required: str = '--input-file ${SOURCES.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle merge subcommand CLI builder

  See the merge CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleMerge": turbo_turtle.scons_extensions.merge(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleMerge(
          target=["target.cae"],
          source=["source1.cae", "source2.cae"],
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.mesh(

  program: str = 'turbo-turtle',
  subcommand: str = 'mesh',
  required: str = '--input-file ${SOURCE.abspath} --output-file ${TARGET.abspath} --element-type ${element_type}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle mesh subcommand CLI builder

  See the mesh CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  Unless the `required` argument is overridden, the following task keyword arguments are required:

  - `element_type`

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleMesh": turbo_turtle.scons_extensions.mesh(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleMesh(
          target=["target.cae"],
          source=["source.cae"],
          element_type="C3D8R"
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.partition(

  program: str = 'turbo-turtle',
  subcommand: str = 'partition',
  required: str = '--input-file ${SOURCE.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle partition subcommand CLI builder

  See the partition CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtlePartition": turbo_turtle.scons_extensions.partition(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtlePartition(
          target=["target.cae"],
          source=["source.cae"],
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.sets(

  program: str = 'turbo-turtle',
  subcommand: str = 'sets',
  required: str = '--input-file ${SOURCE.abspath} --output-file ${TARGET.abspath}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle sets subcommand CLI builder

  See the sets CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  One of the following options must be added to the `options` string or the subcommand will return an error:

  - `--face-set`

  - `--edge-set`

  - `--vertex-set`

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleSets": turbo_turtle.scons_extensions.sets(
              program=env["turbo_turtle],
              options="${face_sets} ${edge_sets} ${vertex_sets}",
          )
      })
      env.TurboTurtleSets(
          target=["target.cae"],
          source=["source.cae"],
          face_sets="--face-set top '[#1 ]' --face-set bottom '[#2 ]'",
          edge_sets="",
          vertex_sets="--vertex-set origin '[#1 ]'"
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

turbo_turtle.scons_extensions.sphere(

  program: str = 'turbo-turtle',
  subcommand: str = 'sphere',
  required: str = '--output-file ${TARGET.abspath} --inner-radius ${inner_radius} --outer-radius ${outer_radius}',
  options: str = '',
  abaqus_command: List[str] = ['abaqus', 'abq2024'],
  cubit_command: List[str] = ['cubit'],
  backend: str = 'abaqus',

) → Builder

  Return a Turbo-Turtle sphere subcommand CLI builder

  See the sphere CLI documentation for detailed subcommand usage and options. Builds subcommand specific options for the `turbo_turtle.scons_extensions.cli_builder()` function.

  At least one target must be specified. The first target determines the working directory for the builder’s action. The action changes the working directory to the first target’s parent directory prior to execution.

  The emitter will assume all emitted targets build in the current build directory. If the target(s) must be built in a build subdirectory, e.g. in a parameterized target build, then the first target must be provided with the build subdirectory, e.g. `parameter_set1/my_target.ext`. When in doubt, provide a STDOUT redirect file as a target, e.g. `target.stdout`.

  Unless the `required` argument is overridden, the following task keyword arguments are required:

  - `inner_radius`

  - `outer_radius`

  action string construction

      ${cd_action_prefix} ${program} ${subcommand} ${required} ${options} --abaqus-command ${abaqus_command} --cubit-command ${cubit_command} --backend ${backend} ${redirect_action_postfix}

  SConstruct

      import waves
      import turbo_turtle
      env = Environment()
      env["turbo_turtle"] = waves.scons_extensions.add_program(env, ["turbo-turtle"])
      env.Append(BUILDERS={
          "TurboTurtleSphere": turbo_turtle.scons_extensions.sphere(
              program=env["turbo_turtle]
          )
      })
      env.TurboTurtleSphere(
          target=["target.cae"],
          source=["SConstruct"],
          inner_radius=1.,
          outer_radius=2.
      )

  Parameters:

    - program (str) – The Turbo-Turtle command line executable absolute or relative path

    - subcommand (str) – A Turbo-Turtle subcommand

    - required (str) – A space delimited string of subcommand required arguments

    - options (str) – A space delimited string of subcommand optional arguments

    - abaqus_command (list) – The Abaqus command line executable absolute or relative path options

    - cubit_command (list) – The Cubit command line executable absolute or relative path options

    - backend (str) – The backend software

## geometry_xyplot

turbo_turtle.geometry_xyplot.geometry_xyplot(

  coordinates_list: list,
  unit_conversion: float = 1.0,
  euclidean_distance: float = 4.0,
  y_offset: float = 0.0,
  rtol: float | None = None,
  atol: float | None = None,
  no_markers: bool = False,
  annotate: bool = False,
  scale: bool = False,

) → <Mock name='mock.pyplot.Figure' id='140521907658560'>

  Return a matplotlib figure with the coordinates plotted consistently with geometry and geometry-xyplot subcommands

  Parameters:

    - coordinates_list – List of 2D numpy arrays of (X, Y) coordinates

    - unit_conversion – multiplication factor applies to all coordinates

    - euclidean_distance – if the distance between two coordinates is greater than this, draw a straight line. Distance should be provided in units after the unit conversion

    - y_offset – vertical offset along the global Y-axis. Offset should be provided in units after the unit conversion.

    - rtol – relative tolerance for vertical/horizontal line checks

    - atol – absolute tolerance for vertical/horizontal line checks

    - no_markers – Exclude vertex markers and only plot lines.

    - annotate – Annotate the vertex coordinates with their index from the source CSV file.

    - scale – Change the plot aspect ratio to use the same scale for the X and Y axes.

  Returns:

    matplotlib figure